@@ -9,11 +9,12 @@ suppressMessages(library(dplyr))
 suppressMessages(library(rlang))
 suppressMessages(library(grid))
 suppressMessages(library(gtable))
+suppressMessages(library(ggpol))
 
 args = commandArgs(trailingOnly = TRUE)
 
 # source facet_share.R
-suppressMessages(source(args[5]))
+# suppressMessages(source(args[5]))
 
 if (length(args) == 0) {
   stop("At least one argument must be supplied (input file).n", call.=FALSE)
@@ -94,17 +95,19 @@ if (length(args) == 0) {
         geom_bar(stat = 'identity', width = 0.8) +
         geom_hline(data = subset(avg_cca, end == 'CA'), aes(yintercept=x), color = "white", alpha = 0.9) + 
         geom_jitter(data = cca_prop_sub[cca_prop_sub$end == "CC",], aes(x = gene, y = bar_pos), size = 0.5, color = "#383D3B", alpha = 0.7) +
-        geom_text(data = subset(avg_cca, end == 'CA'), aes(label = paste(abs(round(x,1)), '%'), x = Inf, y = x), size = 3.3, vjust = 1, color = '#3E606F', fontface='bold') +
+        geom_text(data = subset(avg_cca, end == 'CA'), aes(label = paste(abs(round(x,1)), '%'), x = Inf, y = ifelse(sign(x) == -1 , x + 7, x - 7)), size = 3.3, vjust = 1.5, color = '#3E606F', fontface='bold') +
         facet_share(~condition, dir = "h", scales = "free", reverse_num = TRUE) +
         coord_flip() + 
         scale_fill_manual(name = "", values = alpha(c(CA = "#F0F9ED", CC = "#427AA1", C = "#0D4282", Absent = "#133C55"), 0.8), labels = c("3'-CCA", "3'-CC", "3'-C", "Absent")) +
         scale_y_continuous(breaks = c(c(-100, -75, -50, -25, 0), c(0, 25, 50, 75, 100)))+
         scale_x_discrete(expand = c(0.03, 0)) +
-        theme_minimal() + 
+        theme_bw() + 
         theme(axis.title = element_blank(), 
               strip.text = element_text(face = "bold"), 
               axis.text.y = element_text(size = 9), 
-              axis.text.x = element_text(face = 'bold'))
+              axis.text.x = element_text(face = 'bold'),
+              panel.border = element_blank(),
+              panel.background = element_blank())
       
       ggsave(paste(out, paste(combinations[[i]][1], combinations[[i]][2], out_string, sep = '_'), sep = ''), cca_plot, height = 8, width = 9)
       
